////////////////////////////
// Brickstuff Arduino Shield
//
// Sample code for adding RF remote control functionality
// (c)2020, Enthusiast Enterprises, LLC
//
// THIS CODE IS PROVIDED AS-IS WITH NO WARRANTY OR GUARANTEE OF ANY KIND
//
// HISTORY
// 11.27.2020 Version 1.0
////////////////////////////

// USAGE
//
// This code uses the notion of a "short press" and "long press" of the buttons on the RF remote transmitter to control 8 functions with 4 buttons.
// A "short press" is defined as a button that is pressed for less than 4x the rfPoll delay (defined below in the variables section)-- the default is 400ms or less for a short press
// A "long press" is defined a a button that is pressed for longer than the duration of a short press
//
// You can change the default durations by changing the rfPoll number below-- change at your own risk, however, as making this too long or too short can confuse your users
//
// Make sure to always include the checkRF() subroutine at the end of your code-- this is the section that reads the button inputs.
// This code is written in a non-blocking fashion, meaning you can add other code to run and it will not be interrupted by button presses on the remote.
// A value is only returned from the subroutine when a button has been released after first being pressed.

// RF-related variables
uint8_t rfPins[4] = {2,4,A2,A3};
#define rfPoll 100 // ms delay between reading of the RF ports (for debouncing)
uint8_t rfActive[4] = {0,0,0,0};  // Used in the debounce routine
uint8_t rfCommand[4] = {0,0,0,0}; // Used to deliver debounced (clean) RF commands received from the remote
uint8_t rfStat;
unsigned long rfTick[4];

void setup()
{
  for(uint8_t i=0; i<4; i++)  // Set the RF pins as inputs
  {
    pinMode(rfPins[i], INPUT);
  }
}

void loop()
{
  // Read the RF remote inputs
  rfStat = checkRF(0);  // Button "A"
  if(rfStat == 1) // Short press detected on Button A
  {
    // Put your code here to control what happens with a short press on Button A
  }
  if(rfStat == 2) // Long press detected on Button A
  {
    // Put your code here to control what happens with a long press on Button A
  }
  rfStat = checkRF(1);  // Button "B"
  if(rfStat == 1) // Short press detected on Button B
  {
    // Put your code here to control what happens with a short press on Button B
  }
  if(rfStat == 2) // Long press detected on Button B
  {
    // Put your code here to control what happens with a long press on Button B
  }
  rfStat = checkRF(2);  // Button "C"
  if(rfStat == 1) // Short press detected on Button C
  {
    // Put your code here to control what happens with a short press on Button C
  }
  if(rfStat == 2) // Long press detected on Button C
  {
    // Put your code here to control what happens with a long press on Button C
  }
  rfStat = checkRF(3);  // Button "D"
  if(rfStat == 1) // Short press detected on Button D
  {
    // Put your code here to control what happens with a short press on Button D
  }
  if(rfStat == 2) // Long press detected on Button D
  {
    // Put your code here to control what happens with a long press on Button D
  }
  
  // Put the rest of your code here-- the RF reading routine is non-blocking, so the rest of your code will run even when a button is pressed.
}

// Make sure to include this subroutine at the end of any sketch you write that calls it.
uint8_t checkRF(uint8_t rfPort) // Returns the status of the given RF port (0-3)-- has built-in debounce and only returns a non-zero number after the button is released.  1 = short press, 2 = long press.
{ 
  if(rfActive[rfPort] == 0 && digitalRead(rfPins[rfPort]) == HIGH) // Start the "ON" timer
  {
    rfActive[rfPort] = 1;
    rfCommand[rfPort] = 0;
    rfTick[rfPort] = millis();
  }
  
  if(rfActive[rfPort] > 0 && digitalRead(rfPins[rfPort]) == LOW)
  {
    rfActive[rfPort] = 0;
    if((millis() - rfTick[rfPort]) > rfPoll && (millis() - rfTick[rfPort]) < (rfPoll * 4))
    {
      return 1;
    }
    if(millis() - rfTick[rfPort] >= (rfPoll * 4))
    {
      return 2;
    }
  }
  return 0;
}
